@@ -1271,7 +1271,7 @@ class Shvar(RememberInstanceCreationInfo):
                 i = i + 1
             Hour = Shvar.change_one_to_two_digits(str(max(HourList)))
             TitleMinute = Shvar.change_one_to_two_digits(str(max(AvaillatestMinuteList)))
-            Titletime = Hour + ';' + TitleMinute + ';00'
+            Titletime = Hour + '-' + TitleMinute + '-00'
         else:  # 지정된 시간을 입력한 경우
             if isinstance(Time, int) and len(str(Time)) <= 4:  # 입력은 시간분을 연달아 입력한 4자리 정수여야 한다.
                 zerosnum = 4 - len(str(Time))  # 입력된 정수는 시간값에 의해 3자리일 수 있으며, 이를 4자리 스트링으로 전환한다.
